@@ -1,5 +1,4 @@
 import os
-import re
 
 from importlib import import_module
 from distutils.dir_util import copy_tree
@@ -153,7 +152,9 @@ def get_import_name(app: Flask) -> str:
     return import_name
 
 
-def validate_name(value: str):
-    re_var = re.compile(r"^([A-Za-z_]+[\w]+)$")
-    if not re_var.search(value):
-        raise SystemExit("Error: invalid name %r" % value)
+def get_user_roles(user):
+    roles = {}
+    for role in user.roles:
+        permissions = [perm.name for perm in role.permissions]
+        roles[role.name] = permissions
+    return roles
