@@ -1,5 +1,5 @@
-import re
 from marshmallow import Schema, fields, validates, ValidationError
+from .validators import validate_username
 
 
 class DefaultResponseSchema(Schema):
@@ -22,12 +22,12 @@ class RegisterSchema(LoginSchema):
 
     @validates("first_name")
     def validate_first_name(self, value):
-        if not re.search(r"^([a-zA-Z]*)$", value):
+        if not validate_username(value, silently=True):
             raise ValidationError("First name must be a character [a-zA-Z]")
 
     @validates("last_name")
     def validate_last_name(self, value):
-        if not re.search(r"^([a-zA-Z]*)$", value):
+        if not validate_username(value, silently=True):
             raise ValidationError("Last name must be a character [a-zA-Z]")
 
 
