@@ -5,7 +5,7 @@ from flask_apispec import use_kwargs, marshal_with
 from jwt import DecodeError, ExpiredSignatureError
 from werkzeug.security import generate_password_hash, check_password_hash
 from zemfrog.decorators import auto_status_code
-from zemfrog.helper import db_add, db_update, db_commit, get_mail_template
+from zemfrog.helper import db_add, db_update, db_commit, get_mail_template, get_user_roles
 from zemfrog.models import (
     DefaultResponseSchema,
     LoginSchema,
@@ -16,7 +16,7 @@ from zemfrog.models import (
 )
 
 from {{ "" if main_app else ".." }}models.user import User, Log
-from {{ "" if main_app else ".." }}services.email import send_email
+from {{ "" if main_app else ".." }}tasks.email import send_email
 
 
 @use_kwargs(LoginSchema(strict=True), location="form")
@@ -37,7 +37,9 @@ def login(**kwds):
         log = Log(login_at=login_at)
         user.logs.append(log)
         db_commit()
-        access_token = create_access_token(email)
+        roles = get_user_roles(user)
+        claims = {"roles": roles}
+        access_token = create_access_token(email, user_claims=claims)
         return {"access_token": access_token}
 
     return {"reason": "Incorrect email or password.", "status_code": 404}
@@ -153,6 +155,9 @@ def request_password_reset(**kwds):
                 "request_password_reset.html", link_reset=link_reset
             )
             send_email.delay("Forgot password", html=msg, recipients=[email])
+            log = Log(request_password_reset_at=datetime.utcnow())
+            user.logs.append(log)
+            db_commit()
     else:
         reason = "Email required."
         status_code = 403
@@ -160,6 +165,39 @@ def request_password_reset(**kwds):
     return {"reason": reason, "status_code": status_code}
 
 
+@marshal_with(DefaultResponseSchema, 200)
+@marshal_with(DefaultResponseSchema, 401)
+@marshal_with(DefaultResponseSchema, 403)
+@auto_status_code
+def confirm_password_reset_token(token):
+    """
+    Validate password reset token.
+    """
+
+    try:
+        data = decode_token(token)
+        email = data["identity"]
+        if not data["user_claims"].get("token_password_reset"):
+            raise DecodeError
+
+        user = User.query.filter_by(email=email).first()
+        if user:
+            reason = "Valid token."
+            status_code = 200
+        else:
+            raise DecodeError
+
+    except DecodeError:
+        reason = "Invalid token."
+        status_code = 401
+
+    except ExpiredSignatureError:
+        reason = "Token expired."
+        status_code = 403
+
+    return {"reason": reason, "status_code": status_code}
+
+
 @use_kwargs(PasswordResetSchema(strict=True), location="form")
 @marshal_with(DefaultResponseSchema, 200)
 @marshal_with(DefaultResponseSchema, 403)
@@ -181,6 +219,8 @@ def password_reset(token, **kwds):
         passw = kwds.get("password")
         if user and passw:
             passw = generate_password_hash(passw)
+            log = Log(updated_at=datetime.utcnow())
+            user.logs.append(log)
             db_update(user, password=passw)
             reason = "Successfully change password."
             status_code = 200
