@@ -40,17 +40,27 @@ class Development(object):
         "zemfrog.commands.middleware",
         "zemfrog.commands.command",
         "zemfrog.commands.errorhandler",
+        "zemfrog.commands.extension",
+        "zemfrog.commands.model",
+        "zemfrog.commands.task",
+        "zemfrog.commands.user",
+        "zemfrog.commands.role",
+        "zemfrog.commands.permission",
         {% if main_app -%}
             "zemfrog.commands.app"
         {%- endif %}
     ]
     BLUEPRINTS = ["auth"]
+    STATICFILES = []
     MIDDLEWARES = []
     APIS = []
     ERROR_HANDLERS = {}
     TASKS = []
     API_DOCS = True
     CREATE_DB = True
+    USER_MODEL = "models.user.User"
+    ROLE_MODEL = "models.user.Role"
+    PERMISSION_MODEL = "models.user.Permission"
     CELERY_RESULT_BACKEND = "redis://127.0.0.1:6379"
     CELERY_BROKER_URL = CELERY_RESULT_BACKEND
 
